@@ -20,8 +20,8 @@ sys.path.insert(0, os.path.abspath('..'))
 import importlib.metadata
 
 project = 'Python-SoXR'
-copyright = '2021, Dofuuz'
-author = 'Dofuuz'
+copyright = '2021-22, Myungchul Keum'
+author = 'Myungchul Keum'
 
 # The full version, including alpha/beta/rc tags
 release = importlib.metadata.version('soxr')
